| Title: | Lookup Geolocation and Proxy Information using 'IP2Location.io' API |
|---|---|
| Description: | Query for enriched data such as country, region, city, latitude & longitude, ZIP code, time zone, Autonomous System, Internet Service Provider, domain, net speed, International direct dialing (IDD) code, area code, weather station data, mobile data, elevation, usage type, address type, advertisement category, fraud score, and proxy data with an IP address. You can also query a list of hosted domain names for the IP address too. This package uses the 'IP2Location.io' API to query this data. To get started with a free API key, sign up here <https://www.ip2location.io/sign-up?ref=1>. |
| Authors: | IP2Location.io [aut, cre] |
| Maintainer: | IP2Location.io <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.0 |
| Built: | 2026-05-10 07:55:49 UTC |
| Source: | https://github.com/cran/ip2locationio |
Lookup for a comprehensive of the information such as location, ASN, ISP and proxy. The availability of the data will depends on the plan you have signed up for your API key.
lookup(ip)lookup(ip)
ip |
IPv4 or IPv6 address |
Return all the geolocation and proxy information about the IP address
## Not run: lookup("1.0.241.135") ## End(Not run)## Not run: lookup("1.0.241.135") ## End(Not run)
Lookup for the IP address's Autonomous system name and number
lookupASNByIP(ip)lookupASNByIP(ip)
ip |
IPv4 or IPv6 address |
Return the Autonomous system name and number of the the IP address
## Not run: lookupASNByIP("1.0.241.135") ## End(Not run)## Not run: lookupASNByIP("1.0.241.135") ## End(Not run)
Lookup for the IP address's coordinate
lookupCoordinateByIP(ip)lookupCoordinateByIP(ip)
ip |
IPv4 or IPv6 address |
Return the coordinate of the the IP address
## Not run: lookupCoordinateByIP("1.0.241.135") ## End(Not run)## Not run: lookupCoordinateByIP("1.0.241.135") ## End(Not run)
Lookup for the IP address's country
lookupCountryByIP(ip)lookupCountryByIP(ip)
ip |
IPv4 or IPv6 address |
Return the country name of the the IP address
## Not run: lookupCountryByIP("1.0.241.135") ## End(Not run)## Not run: lookupCountryByIP("1.0.241.135") ## End(Not run)
Lookup for a list of hosted domain names by the IP address.
lookupHostedDomain(ip, page)lookupHostedDomain(ip, page)
ip |
IPv4 or IPv6 address |
page |
(optional) Pagination result returns of the hosted domains. If unspecified, 1st page will be used. |
Return list of hosted domain names by the IP address
## Not run: lookupHostedDomain("1.0.241.135") ## End(Not run)## Not run: lookupHostedDomain("1.0.241.135") ## End(Not run)
Lookup for the IP address's location in text
lookupLocationByIP(ip)lookupLocationByIP(ip)
ip |
IPv4 or IPv6 address |
Return the location of the the IP address in text
## Not run: lookupLocationByIP("1.0.241.135") ## End(Not run)## Not run: lookupLocationByIP("1.0.241.135") ## End(Not run)
Set IP2Location.io API key for lookup. Free API key can be obtained from <https://www.ip2location.io/sign-up?ref=1/>
setApiKey(api_key)setApiKey(api_key)
api_key |
IP2Location.io API key |
No return value, called for side effects.
## Not run: setApiKey("YOUR_API_KEY") ## End(Not run)## Not run: setApiKey("YOUR_API_KEY") ## End(Not run)